emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/image-mode.el,v


From: Karl Fogel
Subject: [Emacs-diffs] Changes to emacs/lisp/image-mode.el,v
Date: Fri, 07 Mar 2008 05:44:39 +0000

CVSROOT:        /cvsroot/emacs
Module name:    emacs
Changes by:     Karl Fogel <kfogel>     08/03/07 05:44:38

Index: image-mode.el
===================================================================
RCS file: /cvsroot/emacs/emacs/lisp/image-mode.el,v
retrieving revision 1.37
retrieving revision 1.38
diff -u -b -r1.37 -r1.38
--- image-mode.el       21 Feb 2008 05:38:30 -0000      1.37
+++ image-mode.el       7 Mar 2008 05:44:34 -0000       1.38
@@ -278,7 +278,7 @@
     map)
   "Major mode keymap for viewing images as text in Image mode.")
 
-(defvar bookmark-make-cell-function)
+(defvar bookmark-make-record-function)
 
 ;;;###autoload
 (defun image-mode ()
@@ -290,8 +290,8 @@
   (setq mode-name "Image[text]")
   (setq major-mode 'image-mode)
   ;; Use our own bookmarking function for images.
-  (set (make-local-variable 'bookmark-make-cell-function)
-       'image-bookmark-make-cell)
+  (set (make-local-variable 'bookmark-make-record-function)
+       'image-bookmark-make-record)
 
   ;; Keep track of [vh]scroll when switching buffers
   (image-mode-setup-winprops)
@@ -431,7 +431,7 @@
 
 ;;; Support for bookmark.el
 
-(defun image-bookmark-make-cell (annotation &rest args)
+(defun image-bookmark-make-record (annotation &rest args)
   (let ((the-record
          `((filename   . ,(buffer-file-name))
           (image-type . ,image-type)
@@ -454,7 +454,7 @@
 ;;;###autoload
 (defun image-bookmark-jump (bmk)
   ;; This implements the `handler' function interface for record type
   ;; returned by `bookmark-make-cell-function', which see.
   (save-window-excursion
     (let ((filename (bookmark-get-filename bmk))
          (type (cdr (assq 'image-type (bookmark-get-bookmark-record bmk))))
@@ -454,7 +454,7 @@
 (defun image-bookmark-jump (bmk)
   ;; This implements the `handler' function interface for record type
-  ;; returned by `bookmark-make-cell-function', which see.
+  ;; returned by `bookmark-make-record-function', which see.
   (save-window-excursion
     (let ((filename (bookmark-get-filename bmk))




reply via email to

[Prev in Thread] Current Thread [Next in Thread]